CompGCN
=======

.. currentmodule:: pykeen.models

.. autoclass:: CompGCN
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CompGCN.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
